@@ -1,5 +1,4 @@
 #[allow(dead_code)]
-use std::io::{Error,ErrorKind};
 //------------------------
 mod get_dirs_all; 
 pub use get_dirs_all::*;
@@ -9,14 +8,18 @@ mod direntry_to_path_all;
 pub use direntry_to_path_all::*;
 mod get_entries; 
 pub use get_entries::*;
-mod write_file;
-pub use write_file::write_file;
+mod write_to_file;
+pub use write_to_file::write_to_file;
 mod get_files;
 pub use get_files::get_files;
 mod create_file;
 pub use create_file::create_file;
 mod create_dir;
 pub use create_dir::create_dir;
+mod create_dir_brute;
+pub use create_dir_brute::create_dir_brute;
+mod create_dir_all;
+pub use create_dir_all::create_dir_all;
 mod get_read_dir;
 pub use get_read_dir::get_read_dir;
 mod get_ext;
@@ -43,8 +46,8 @@ mod is_file;
 pub use is_file::is_file;
 //------------------------
 
-mod copy_dir_structure;
-pub use copy_dir_structure::copy_dir_structure;
+mod clone_dir_structure;
+pub use clone_dir_structure::clone_dir_structure;
 
 mod create_dir_structure;
 pub use create_dir_structure::create_dir_structure;
@@ -52,15 +55,3 @@ pub use create_dir_structure::create_dir_structure;
 mod dir_structure_to_string;
 pub use dir_structure_to_string::dir_structure_to_string;
 //------------------------
-
-pub fn bool_to_result(input:bool,message:&str)->Result<bool,Error>{
-    match input {
-        true=>{
-            return Ok(true);
-        },
-        false=>{
-            let e = Error::new(ErrorKind::InvalidData,message);
-            return Err(e);
-        },
-    }
-}
